@@ -5,5 +5,5 @@ This pachage contains the L{Morse} class. This class implements the engine.
 Additionally there is a L{KochLesson} class that can be used as a char-source 
 for Morse. """
 
-from morse import Morse
-from koch import KochLesson 
+from .morse import Morse
+from .koch import KochLesson 
