@@ -21,7 +21,7 @@ class KochLesson:
         return self
 
 
-    def next(self):
+    def __next__(self):
         c = self._get_next_char()
         while c in self.__chars_ignored and c != " ":
             c = self._get_next_char()
@@ -42,7 +42,7 @@ class KochLesson:
         if self.__prefer_last:
             def exp_prop(lst):
                 if len(lst) <= 1: return lst
-                return lst+exp_prop(lst[len(lst)/2:])
+                return lst+exp_prop(lst[len(lst)//2:])
             return choice(exp_prop(self.chars[:self.__lesson]))
         else:
             return choice(self.chars[:self.__lesson])
