@@ -112,7 +112,7 @@ class Morse(Thread):
         self.__buffer_len     = self.__dit_len*2
 
         # calculate dit-sample:
-        self.__dit_sample = str()
+        self.__dit_sample = bytes()
         w = 2.0*pi * self.__frequency/self.__sample_rate
         for i in range(self.__dit_len):  # calc sine tone
             if i <= period_len:
@@ -121,11 +121,11 @@ class Morse(Thread):
                 value = float(self.__dit_len-i)/period_len * self.__volume * sin(omega * float(i))
             else:
                 value = self.__volume * sin(omega * float(i))
-            self.__dit_sample += struct.pack("<h", value)
-        self.__dit_sample += struct.pack("<h", 0.0)*self.__dit_len
+            self.__dit_sample += struct.pack("<h", int(value))
+        self.__dit_sample += struct.pack("<h", 0)*self.__dit_len
 
         #calculate da-sample:
-        self.__da_sample = str()
+        self.__da_sample = bytes()
         for i in range( self.__da_len ):
             if i <= period_len:
                 value = float(i)/period_len * self.__volume*sin(omega * float(i))
@@ -133,12 +133,12 @@ class Morse(Thread):
                 value = float(self.__da_len-i)/period_len * self.__volume * sin(omega * float(i))
             else:
                 value = self.__volume * sin(omega * float(i))
-            self.__da_sample += struct.pack("<h", value)
-        self.__da_sample += struct.pack("<h", 0.0)*self.__dit_len
+            self.__da_sample += struct.pack("<h", int(value))
+        self.__da_sample += struct.pack("<h", 0)*self.__dit_len
 
         # "calculate" pause-sample:
-        self.__cpause_sample = struct.pack("<h", 0.0)*self.__char_pause_len
-        self.__wpause_sample = struct.pack("<h", 0.0)*self.__word_pause_len
+        self.__cpause_sample = struct.pack("<h", 0)*self.__char_pause_len
+        self.__wpause_sample = struct.pack("<h", 0)*self.__word_pause_len
 
         # set buffer size:
         self.__pcm.setperiodsize(self.__buffer_len)
