@@ -1,14 +1,12 @@
 #!/usr/bin/python
 
-import gtk
-import gtk.glade
-import gobject
+from gi.repository import GObject, Gdk, Gtk
 import time 
 import os.path
 
-import alsamorse
-from propdialog import PropertyDialog
-from conffile import Config
+from . import alsamorse
+from .propdialog import PropertyDialog
+from .conffile import Config
 
 
 
@@ -17,18 +15,19 @@ from conffile import Config
 class KochMorse:
 
     def __init__(self):
-        self.__gladefile = os.path.join(os.path.dirname(__file__), "kochmorse.glade")
-        self.__xml = gtk.glade.XML(self.__gladefile, "window1")
-        self.__window     = self.__xml.get_widget("window1")
-        self.__textview   = self.__xml.get_widget("textview")
-        self.__statusbar  = self.__xml.get_widget("statusbar")
-        self.__speedspin  = self.__xml.get_widget("speedspin")
-        self.__effspeed   = self.__xml.get_widget("effspeedspin")
-        self.__lessonspin = self.__xml.get_widget("lessonspin")
-        self.__freqspin   = self.__xml.get_widget("freqspin")
-        self.__timelabel  = self.__xml.get_widget("timelabel")
-        self.__playbutton = self.__xml.get_widget("playbutton")
-        self.__volume     = self.__xml.get_widget("volume")
+        self.__gladefile = os.path.join(os.path.dirname(__file__), "kochmorse.ui")
+        self.__xml = Gtk.Builder()
+        self.__xml.add_from_file(self.__gladefile)
+        self.__window     = self.__xml.get_object("window1")
+        self.__textview   = self.__xml.get_object("textview")
+        self.__statusbar  = self.__xml.get_object("statusbar")
+        self.__speedspin  = self.__xml.get_object("speedspin")
+        self.__effspeed   = self.__xml.get_object("effspeedspin")
+        self.__lessonspin = self.__xml.get_object("lessonspin")
+        self.__freqspin   = self.__xml.get_object("freqspin")
+        self.__timelabel  = self.__xml.get_object("timelabel")
+        self.__playbutton = self.__xml.get_object("playbutton")
+        self.__volume     = self.__xml.get_object("volume")
 
         # load config and set entries
         self.__config = Config()
@@ -51,7 +50,7 @@ class KochMorse:
 
         self.__lessonspin.set_range(2, self.__lesson.get_num_lessons())
 
-        self.__xml.signal_autoconnect({
+        self.__xml.connect_signals({
                 'on_playbutton_toggled': self.on_play_toggled,
                 'on_quit': self.on_quit,
                 'on_info_show': self.on_info_show,
@@ -62,7 +61,7 @@ class KochMorse:
                 'on_lesson_changed': self.on_lesson_changed,
                 'on_freq_changed': self.on_freq_changed})
 
-        gobject.timeout_add(500, self.on_update_time)
+        GObject.timeout_add(500, self.on_update_time)
         
 
     def on_play_toggled(self, button):
@@ -77,9 +76,10 @@ class KochMorse:
 
 
     def on_info_show(self, button):
-        info_file = os.path.join(os.path.dirname(__file__), "infodialog.glade")
-        info_xml = gtk.glade.XML(info_file, "infodialog");
-        info_dialog = info_xml.get_widget("infodialog")
+        info_file = os.path.join(os.path.dirname(__file__), "infodialog.ui")
+        info_xml = Gtk.Builder()
+        info_xml.add_from_file(info_file);
+        info_dialog = info_xml.get_object("infodialog")
         info_dialog.run()
         info_dialog.destroy()
 
@@ -93,14 +93,14 @@ class KochMorse:
 
     def on_quit(self, window):
         self.__engine.stop()
-        gtk.main_quit()
+        Gtk.main_quit()
 
 
     def on_char_send(self, char):
-        gtk.gdk.threads_enter()
+        Gdk.threads_enter()
         self.__textview.get_buffer().insert_at_cursor(char)        
         self.__statusbar.push(1, "%i chars send"%self.__lesson.get_chars_send())
-        gtk.gdk.threads_leave()
+        Gdk.threads_leave()
 
     
     def on_update_time(self):
