@@ -1,17 +1,18 @@
-import gtk
+from gi.repository import Gtk
 import os.path
-from conffile import Config
-from alsamorse import KochLesson
+from .conffile import Config
+from .alsamorse import KochLesson
 
 class PropertyDialog:
     def __init__(self):
-        self.__gladefile = os.path.join(os.path.dirname(__file__), "propdialog.glade")
-        self.__xml = gtk.glade.XML(self.__gladefile,"propdialog")
-        self.__widget = self.__xml.get_widget("propdialog")
-        self.__lessontime = self.__xml.get_widget("lessontime")
-        self.__countdown  = self.__xml.get_widget("countdown")
-        self.__prefer_last = self.__xml.get_widget("prefer_last")
-        self.__ign_box = self.__xml.get_widget("ignorechars")
+        self.__gladefile = os.path.join(os.path.dirname(__file__), "propdialog.ui")
+        self.__xml = Gtk.Builder()
+        self.__xml.add_from_file(self.__gladefile)
+        self.__widget = self.__xml.get_object("propdialog")
+        self.__lessontime = self.__xml.get_object("lessontime")
+        self.__countdown  = self.__xml.get_object("countdown")
+        self.__prefer_last = self.__xml.get_object("prefer_last")
+        self.__ign_box = self.__xml.get_object("ignorechars")
         
         cfg = Config()
         self.__lessontime.set_value(cfg.opt_lessontime)
@@ -22,13 +23,10 @@ class PropertyDialog:
             
 
     def run(self):
-        if self.__widget.run() == gtk.RESPONSE_CANCEL:
+        if self.__widget.run() == Gtk.ResponseType.CANCEL:
             self.__widget.destroy()
             return None
 
-        
-
-
         cfg = Config()
         cfg.opt_lessontime  = self.__lessontime.get_value()
         cfg.opt_countdown   = self.__countdown.get_value()
